package com.benyun.controller;


import com.benyun.boot.core.vo.Result;
import com.benyun.entity.EventAppendix;
import com.benyun.service.EventAppendixService;
import lombok.RequiredArgsConstructor;
import org.beetl.sql.core.engine.PageQuery;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.net.URLEncoder;
import java.util.List;

/**
 * 事件附件表
 *
 * @author makejava
 * create on 2023-03-27 08:55:05
 */
@RestController
@RequestMapping("eventAppendix")
@RequiredArgsConstructor(onConstructor_ = {@Autowired})
public class EventAppendixController {
    /**
     * 服务对象
     */
    private final EventAppendixService eventAppendixService;

    /**
     * 查询所有数据
     *
     * @return 所有数据
     */
    @GetMapping("/queryAll")
    public Result<List<EventAppendix>> queryAll() {
        return Result.success(eventAppendixService.queryAll());
    }

    /**
     * 分页查询数据
     *
     * @return 所有数据
     */
    @GetMapping("/queryPage")
    public Result<List<EventAppendix>> queryPage(@RequestParam Integer pageNum, @RequestParam Integer pageSize, EventAppendix eventAppendix) {
        PageQuery<EventAppendix> pageQuery = new PageQuery<EventAppendix>();
        pageQuery.setPageSize(pageSize);
        pageQuery.setPageNumber(pageNum);
        pageQuery.setParas(eventAppendix);
        return eventAppendixService.queryByPage(pageQuery);
    }

    /**
     * 通过主键查询单条数据
     *
     * @param id 主键
     * @return 单条数据
     */
    @GetMapping("/queryOne")
    public Result<EventAppendix> queryOne(@RequestParam("id") Integer id) {
        return Result.success(eventAppendixService.queryById(id));
    }

    /**
     * 通过eventId查询数据
     *
     * @param eventId 事件ID
     * @return 单条数据
     */
    @GetMapping("/queryListByEventId")
    public Result<List<EventAppendix>> queryListByEventId(@RequestParam("eventId") String eventId) {
        return Result.success(eventAppendixService.queryListByEventId(eventId));
    }

    /**
     * 新增数据
     *
     * @param eventAppendix 实体对象
     * @return 新增结果
     */
    @PostMapping("/create")
    public Result<?> create(@RequestBody EventAppendix eventAppendix) {
        eventAppendixService.insert(eventAppendix);
        return Result.success(eventAppendix);
    }

    /**
     * 上传附件
     *
     * @return 上传结果
     */
    @PostMapping
    public Result<Boolean> upload(@RequestPart("file") MultipartFile file, @RequestParam("id") String id) {
        return Result.success(eventAppendixService.saveAppendix(file, id));
    }

    /**
     * 下载附件
     *
     */
    @GetMapping("/download")
    public void download(HttpServletResponse response, @RequestParam("id") Integer id) throws IOException {
        EventAppendix eventAppendix = eventAppendixService.queryById(id);
        response.setContentType("application/octet-stream");
        response.setCharacterEncoding("utf-8");
        response.addHeader("Content-disposition", "attachment;");
        byte[] bytes = eventAppendixService.simpleAppendix(response, eventAppendix);
        response.getOutputStream().write(bytes);
        response.getOutputStream().close();
    }

    /**
     * 修改数据
     *
     * @param eventAppendix 实体对象
     * @return 修改结果
     */
    @PostMapping("/update")
    public Result<?> update(@RequestBody EventAppendix eventAppendix) {
        return eventAppendixService.updateById(eventAppendix) ? Result.success() : Result.failure();
    }

    /**
     * 删除数据
     *
     * @param id 主键
     * @return 删除结果
     */
    @PostMapping("/delete")
    public Result<Boolean> delete(@RequestParam("id") Integer id) {
        EventAppendix eventAppendix = eventAppendixService.queryById(id);
        if (eventAppendixService.deleteFile(eventAppendix))
            return Result.success(this.eventAppendixService.deleteById(id));
        else return Result.success(false);
    }


}
