package com.benyun.service.impl;


import java.util.List;

import com.benyun.entity.EventLog;
import com.benyun.dao.EventLogDao;
import com.benyun.service.EventLogService;
import com.benyun.boot.core.vo.Result;
import com.benyun.vo.EventLogPageVo;
import com.benyun.vo.EventLogVo;
import lombok.RequiredArgsConstructor;
import org.springframework.stereotype.Service;
import org.beetl.sql.core.engine.PageQuery;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.transaction.annotation.Transactional;
/**
 * 日志信息表(EventLog)表服务实现
 *
 * @author makejava
 * create on 2023-03-22 09:25:07
 */
@Service
@RequiredArgsConstructor(onConstructor_ = {@Autowired})
public class EventLogServiceImpl implements EventLogService {

    private final EventLogDao eventLogDao;

    @Override
    public EventLogVo queryById(Integer id) {
        return eventLogDao.queryById(id);
    }

    @Override
    public List<EventLog> queryAll() {
        return eventLogDao.all();
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public void insert(EventLog eventLog) {
        eventLogDao.insert(eventLog, true);
    }
    
    /**
     * 根据主键更新记录
     *
     * @param eventLog 待更新的记录.包含主键在内，如果其他列的值为空则不更新
     * @return 成功返回true，失败返回false
     */
    @Override
    public boolean updateById(EventLog eventLog) {
        return eventLogDao.updateTemplateById(eventLog) > 0;
    }
    
    /**
     * 根据主键删除记录
     *
     * @param id 主键
     * @return 成功返回true，反之返回false
     */
    @Override
    public boolean deleteById(Integer id) {
        return eventLogDao.deleteById(id) > 0;
    }
    
    /**
     * 分页查询
     * @param pageQuery 封装分页条件的分页对象
     * @return pageQuery 作为一个引用，将查询结果封装进去
     */
    @Override
    public Result<List<EventLog>> queryByPage(PageQuery<EventLog> pageQuery) {
        eventLogDao.queryByPage(pageQuery);
        Result<List<EventLog>> result = Result.success();
        result.setData(pageQuery.getList());
        result.setCount((int) pageQuery.getTotalRow());
        return result;
    }

    /**
     * 分页查询2
     * @param pageQuery 封装分页条件的分页对象
     * @return pageQuery 作为一个引用，将查询结果封装进去
     */
    @Override
    public EventLogPageVo queryByPage2(PageQuery<EventLogVo> pageQuery) {
        eventLogDao.queryByPage2(pageQuery);
        EventLogPageVo eventLogPageVo = new EventLogPageVo();
        eventLogPageVo.setTotalRow((int) pageQuery.getTotalRow());
        eventLogPageVo.setEventLogVos(pageQuery.getList());
        return eventLogPageVo;
    }

    @Override
    public void insertList(List<EventLog> eventLogList) {
        eventLogDao.insertBatch(eventLogList);
    }
}
