package com.benyun.service.impl;


import java.util.List;

import com.benyun.entity.User;
import com.benyun.dao.UserDao;
import com.benyun.service.UserService;
import com.benyun.boot.core.vo.Result;
import lombok.RequiredArgsConstructor;
import org.springframework.stereotype.Service;
import org.beetl.sql.core.engine.PageQuery;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.transaction.annotation.Transactional;
/**
 * 用户信息表(User)表服务实现
 *
 * @author makejava
 * create on 2023-03-17 09:06:58
 */
@Service
@RequiredArgsConstructor(onConstructor_ = {@Autowired})
public class UserServiceImpl implements UserService {

    private final UserDao userDao;

    @Override
    public User queryById(Integer id) {
        return userDao.single(id);
    }

    @Override
    public List<User> queryAll() {
        return userDao.all();
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public void insert(User user) {
        userDao.insert(user, true);
    }
    
    /**
     * 根据主键更新记录
     *
     * @param user 待更新的记录.包含主键在内，如果其他列的值为空则不更新
     * @return 成功返回true，失败返回false
     */
    @Override
    public boolean updateById(User user) {
        return userDao.updateTemplateById(user) > 0;
    }
    
    /**
     * 根据主键删除记录
     *
     * @param id 主键
     * @return 成功返回true，反之返回false
     */
    @Override
    public boolean deleteById(Integer id) {
        return userDao.deleteById(id) > 0;
    }
    
    /**
     * 分页查询
     * @param pageQuery 封装分页条件的分页对象
     * @return pageQuery 作为一个引用，将查询结果封装进去
     */
    @Override
    public Result<List<User>> queryByPage(PageQuery<User> pageQuery) {
        userDao.queryByPage(pageQuery);
        Result<List<User>> result = Result.success();
        result.setData(pageQuery.getList());
        result.setCount((int) pageQuery.getTotalRow());
        return result;
    }
}
